Test: _ Won't highlight _

Test: Will highlight

Test: I'm italic and bold I am just bold.

Test: I'm bold and italic! I am just italic.

Test: A lot of asterisks************is okay

Test: This will all be bold **because of the placement of the center asterisk.

Test: This will all be bold ** because of the placement of the center asterisk.

Test: This will NOT all be bold because of the placement of the center asterisk.**

Test: This will all be bold* because the token is less than that of the surrounding.

Test: This is text bold italic bold with more text

Test: All will _ be italic

Test: All will _be italic

Test: All will not be italic_

Test: All will not _ be italic_

Test: All will _ be bold

Test: All will _be italic_

Test: All will not_ be bold__

Test: All will not _ be bold__

Test: This is text bold italic bold with more text

Test: test test test test

Test: test* test *test

Test: test * test

Test: test ** test

Test: test test test test

Test: test test _test_

Test: test _ test

Test: test __ test

Test: test (test) test

Test: test (test) test